@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -41,9 +41,7 @@ QSflPhoneDialer::QSflPhoneDialer(const QString &applicationName)
 {
 }
 
-QSflPhoneDialer::~QSflPhoneDialer()
-{
-}
+QSflPhoneDialer::~QSflPhoneDialer() = default;
 
 bool QSflPhoneDialer::initializeSflPhone()
 {
